==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicefabric/kotlin/inputs/VaultCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabric.kotlin.inputs

import com.pulumi.azurenative.servicefabric.inputs.VaultCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a single certificate reference in a Key Vault, and where the certificate should reside on the VM.
 * @property certificateStore For Windows VMs, specifies the certificate store on the Virtual Machine to which the certificate should be added. The specified certificate store is implicitly in the LocalMachine account. <br><br>For Linux VMs, the certificate file is placed under the /var/lib/waagent directory, with the file name <UppercaseThumbprint>.crt for the X509 certificate file and <UppercaseThumbprint>.prv for private key. Both of these files are .pem formatted.
 * @property certificateUrl This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a secret to the Key Vault, see [Add a key or secret to the key vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case, your certificate needs to be It is the Base64 encoding of the following JSON Object which is encoded in UTF-8: <br><br> {<br>  "data":"<Base64-encoded-certificate>",<br>  "dataType":"pfx",<br>  "password":"<pfx-file-password>"<br>}
 */
public data class VaultCertificateArgs(
    public val certificateStore: Output<String>,
    public val certificateUrl: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabric.inputs.VaultCertificateArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabric.inputs.VaultCertificateArgs =
        com.pulumi.azurenative.servicefabric.inputs.VaultCertificateArgs.builder()
            .certificateStore(certificateStore.applyValue({ args0 -> args0 }))
            .certificateUrl(certificateUrl.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VaultCertificateArgs].
 */
@PulumiTagMarker
public class VaultCertificateArgsBuilder internal constructor() {
    private var certificateStore: Output<String>? = null

    private var certificateUrl: Output<String>? = null

    /**
     * @param value For Windows VMs, specifies the certificate store on the Virtual Machine to which the certificate should be added. The specified certificate store is implicitly in the LocalMachine account. <br><br>For Linux VMs, the certificate file is placed under the /var/lib/waagent directory, with the file name <UppercaseThumbprint>.crt for the X509 certificate file and <UppercaseThumbprint>.prv for private key. Both of these files are .pem formatted.
     */
    @JvmName("lvvpkhyegffmvycb")
    public suspend fun certificateStore(`value`: Output<String>) {
        this.certificateStore = value
    }

    /**
     * @param value This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a secret to the Key Vault, see [Add a key or secret to the key vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case, your certificate needs to be It is the Base64 encoding of the following JSON Object which is encoded in UTF-8: <br><br> {<br>  "data":"<Base64-encoded-certificate>",<br>  "dataType":"pfx",<br>  "password":"<pfx-file-password>"<br>}
     */
    @JvmName("nvadegcvklfkodac")
    public suspend fun certificateUrl(`value`: Output<String>) {
        this.certificateUrl = value
    }

    /**
     * @param value For Windows VMs, specifies the certificate store on the Virtual Machine to which the certificate should be added. The specified certificate store is implicitly in the LocalMachine account. <br><br>For Linux VMs, the certificate file is placed under the /var/lib/waagent directory, with the file name <UppercaseThumbprint>.crt for the X509 certificate file and <UppercaseThumbprint>.prv for private key. Both of these files are .pem formatted.
     */
    @JvmName("pyafldiomafwcnne")
    public suspend fun certificateStore(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateStore = mapped
    }

    /**
     * @param value This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a secret to the Key Vault, see [Add a key or secret to the key vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case, your certificate needs to be It is the Base64 encoding of the following JSON Object which is encoded in UTF-8: <br><br> {<br>  "data":"<Base64-encoded-certificate>",<br>  "dataType":"pfx",<br>  "password":"<pfx-file-password>"<br>}
     */
    @JvmName("isgxyrfjufoforud")
    public suspend fun certificateUrl(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateUrl = mapped
    }

    internal fun build(): VaultCertificateArgs = VaultCertificateArgs(
        certificateStore = certificateStore ?: throw PulumiNullFieldException("certificateStore"),
        certificateUrl = certificateUrl ?: throw PulumiNullFieldException("certificateUrl"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicefabric/kotlin/inputs/VaultCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabric.kotlin.inputs

import com.pulumi.azurenative.servicefabric.inputs.VaultCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a single certificate reference in a Key Vault, and where the certificate should reside on the VM.
 * @property certificateStore For Windows VMs, specifies the certificate store on the Virtual Machine to which the certificate should be added. The specified certificate store is implicitly in the LocalMachine account. <br><br>For Linux VMs, the certificate file is placed under the /var/lib/waagent directory, with the file name <UppercaseThumbprint>.crt for the X509 certificate file and <UppercaseThumbprint>.prv for private key. Both of these files are .pem formatted.
 * @property certificateUrl This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a secret to the Key Vault, see [Add a key or secret to the key vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case, your certificate needs to be It is the Base64 encoding of the following JSON Object which is encoded in UTF-8: <br><br> {<br>  "data":"<Base64-encoded-certificate>",<br>  "dataType":"pfx",<br>  "password":"<pfx-file-password>"<br>}
 */
public data class VaultCertificateArgs(
    public val certificateStore: Output<String>,
    public val certificateUrl: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabric.inputs.VaultCertificateArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabric.inputs.VaultCertificateArgs =
        com.pulumi.azurenative.servicefabric.inputs.VaultCertificateArgs.builder()
            .certificateStore(certificateStore.applyValue({ args0 -> args0 }))
            .certificateUrl(certificateUrl.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VaultCertificateArgs].
 */
@PulumiTagMarker
public class VaultCertificateArgsBuilder internal constructor() {
    private var certificateStore: Output<String>? = null

    private var certificateUrl: Output<String>? = null

    /**
     * @param value For Windows VMs, specifies the certificate store on the Virtual Machine to which the certificate should be added. The specified certificate store is implicitly in the LocalMachine account. <br><br>For Linux VMs, the certificate file is placed under the /var/lib/waagent directory, with the file name <UppercaseThumbprint>.crt for the X509 certificate file and <UppercaseThumbprint>.prv for private key. Both of these files are .pem formatted.
     */
    @JvmName("uoqrpoxsxvnqvqvy")
    public suspend fun certificateStore(`value`: Output<String>) {
        this.certificateStore = value
    }

    /**
     * @param value This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a secret to the Key Vault, see [Add a key or secret to the key vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case, your certificate needs to be It is the Base64 encoding of the following JSON Object which is encoded in UTF-8: <br><br> {<br>  "data":"<Base64-encoded-certificate>",<br>  "dataType":"pfx",<br>  "password":"<pfx-file-password>"<br>}
     */
    @JvmName("myftagmcjrcudefg")
    public suspend fun certificateUrl(`value`: Output<String>) {
        this.certificateUrl = value
    }

    /**
     * @param value For Windows VMs, specifies the certificate store on the Virtual Machine to which the certificate should be added. The specified certificate store is implicitly in the LocalMachine account. <br><br>For Linux VMs, the certificate file is placed under the /var/lib/waagent directory, with the file name <UppercaseThumbprint>.crt for the X509 certificate file and <UppercaseThumbprint>.prv for private key. Both of these files are .pem formatted.
     */
    @JvmName("aslqxtvebsmytqvk")
    public suspend fun certificateStore(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateStore = mapped
    }

    /**
     * @param value This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a secret to the Key Vault, see [Add a key or secret to the key vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case, your certificate needs to be It is the Base64 encoding of the following JSON Object which is encoded in UTF-8: <br><br> {<br>  "data":"<Base64-encoded-certificate>",<br>  "dataType":"pfx",<br>  "password":"<pfx-file-password>"<br>}
     */
    @JvmName("xjqafhgjwnqxpkpo")
    public suspend fun certificateUrl(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateUrl = mapped
    }

    internal fun build(): VaultCertificateArgs = VaultCertificateArgs(
        certificateStore = certificateStore ?: throw PulumiNullFieldException("certificateStore"),
        certificateUrl = certificateUrl ?: throw PulumiNullFieldException("certificateUrl"),
    )
}
